#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>

class RedditSession;
class CommentView;
class QListWidgetItem;

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow {
    Q_OBJECT
public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();

    void start();
    void setupCategories();


private slots:

    void itemActivated(QListWidgetItem*);

    void populate();
    void changeCategory();

protected:
    void changeEvent(QEvent *e);

private:
    Ui::MainWindow *ui;
    RedditSession* m_ses;
    CommentView* m_com;

};

#endif // MAINWINDOW_H
